==> webkit2gtk_2.18.6.orig.tar.xz: webkitgtk-2.18.6/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMHTMLHRElement.cpp <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "WebKitDOMHTMLHRElement.h"

#include <WebCore/CSSImportRule.h>
#include "DOMObjectCache.h"
#include <WebCore/DOMException.h>
#include <WebCore/Document.h>
#include "GObjectEventListener.h"
#include <WebCore/HTMLNames.h>
#include <WebCore/JSMainThreadExecState.h>
#include "WebKitDOMEventPrivate.h"
#include "WebKitDOMEventTarget.h"
#include "WebKitDOMHTMLHRElementPrivate.h"
#include "WebKitDOMNodePrivate.h"
#include "WebKitDOMPrivate.h"
#include "ConvertToUTF8String.h"
#include <wtf/GetPtr.h>
#include <wtf/RefPtr.h>

namespace WebKit {

WebKitDOMHTMLHRElement* kit(WebCore::HTMLHRElement* obj)
{
    return WEBKIT_DOM_HTML_HR_ELEMENT(kit(static_cast<WebCore::Node*>(obj)));
}

WebCore::HTMLHRElement* core(WebKitDOMHTMLHRElement* request)
{
    return request ? static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(request)->coreObject) : 0;
}

WebKitDOMHTMLHRElement* wrapHTMLHRElement(WebCore::HTMLHRElement* coreObject)
{
    ASSERT(coreObject);
    return WEBKIT_DOM_HTML_HR_ELEMENT(g_object_new(WEBKIT_DOM_TYPE_HTML_HR_ELEMENT, "core-object", coreObject, nullptr));
}

} // namespace WebKit

static gboolean webkit_dom_html_hr_element_dispatch_event(WebKitDOMEventTarget* target, WebKitDOMEvent* event, GError** error)
{
    WebCore::Event* coreEvent = WebKit::core(event);
    if (!coreEvent)
        return false;
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);

    auto result = coreTarget->dispatchEventForBindings(*coreEvent);
    if (result.hasException()) {
        auto description = WebCore::DOMException::description(result.releaseException().code());
        g_set_error_literal(error, g_quark_from_string("WEBKIT_DOM"), description.legacyCode, description.name);
        return false;
    }
    return result.releaseReturnValue();
}

static gboolean webkit_dom_html_hr_element_add_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::addEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static gboolean webkit_dom_html_hr_element_remove_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::removeEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static void webkit_dom_event_target_init(WebKitDOMEventTargetIface* iface)
{
    iface->dispatch_event = webkit_dom_html_hr_element_dispatch_event;
    iface->add_event_listener = webkit_dom_html_hr_element_add_event_listener;
    iface->remove_event_listener = webkit_dom_html_hr_element_remove_event_listener;
}

G_DEFINE_TYPE_WITH_CODE(WebKitDOMHTMLHRElement, webkit_dom_html_hr_element, WEBKIT_DOM_TYPE_HTML_ELEMENT, G_IMPLEMENT_INTERFACE(WEBKIT_DOM_TYPE_EVENT_TARGET, webkit_dom_event_target_init))

enum {
    PROP_0,
    PROP_ALIGN,
    PROP_NO_SHADE,
    PROP_SIZE,
    PROP_WIDTH,
};

static void webkit_dom_html_hr_element_set_property(GObject* object, guint propertyId, const GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLHRElement* self = WEBKIT_DOM_HTML_HR_ELEMENT(object);

    switch (propertyId) {
    case PROP_ALIGN:
        webkit_dom_html_hr_element_set_align(self, g_value_get_string(value));
        break;
    case PROP_NO_SHADE:
        webkit_dom_html_hr_element_set_no_shade(self, g_value_get_boolean(value));
        break;
    case PROP_SIZE:
        webkit_dom_html_hr_element_set_size(self, g_value_get_string(value));
        break;
    case PROP_WIDTH:
        webkit_dom_html_hr_element_set_width(self, g_value_get_string(value));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_hr_element_get_property(GObject* object, guint propertyId, GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLHRElement* self = WEBKIT_DOM_HTML_HR_ELEMENT(object);

    switch (propertyId) {
    case PROP_ALIGN:
        g_value_take_string(value, webkit_dom_html_hr_element_get_align(self));
        break;
    case PROP_NO_SHADE:
        g_value_set_boolean(value, webkit_dom_html_hr_element_get_no_shade(self));
        break;
    case PROP_SIZE:
        g_value_take_string(value, webkit_dom_html_hr_element_get_size(self));
        break;
    case PROP_WIDTH:
        g_value_take_string(value, webkit_dom_html_hr_element_get_width(self));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_hr_element_class_init(WebKitDOMHTMLHRElementClass* requestClass)
{
    GObjectClass* gobjectClass = G_OBJECT_CLASS(requestClass);
    gobjectClass->set_property = webkit_dom_html_hr_element_set_property;
    gobjectClass->get_property = webkit_dom_html_hr_element_get_property;

    g_object_class_install_property(
        gobjectClass,
        PROP_ALIGN,
        g_param_spec_string(
            "align",
            "HTMLHRElement:align",
            "read-write gchar* HTMLHRElement:align",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_NO_SHADE,
        g_param_spec_boolean(
            "no-shade",
            "HTMLHRElement:no-shade",
            "read-write gboolean HTMLHRElement:no-shade",
            FALSE,
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_SIZE,
        g_param_spec_string(
            "size",
            "HTMLHRElement:size",
            "read-write gchar* HTMLHRElement:size",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        PROP_WIDTH,
        g_param_spec_string(
            "width",
            "HTMLHRElement:width",
            "read-write gchar* HTMLHRElement:width",
            "",
            WEBKIT_PARAM_READWRITE));

}

static void webkit_dom_html_hr_element_init(WebKitDOMHTMLHRElement* request)
{
    UNUSED_PARAM(request);
}

gchar* webkit_dom_html_hr_element_get_align(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::alignAttr));
    return result;
}

void webkit_dom_html_hr_element_set_align(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::alignAttr, convertedValue);
}

gboolean webkit_dom_html_hr_element_get_no_shade(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), FALSE);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gboolean result = item->hasAttributeWithoutSynchronization(WebCore::HTMLNames::noshadeAttr);
    return result;
}

void webkit_dom_html_hr_element_set_no_shade(WebKitDOMHTMLHRElement* self, gboolean value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    WebCore::HTMLHRElement* item = WebKit::core(self);
    item->setBooleanAttribute(WebCore::HTMLNames::noshadeAttr, value);
}

gchar* webkit_dom_html_hr_element_get_size(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::sizeAttr));
    return result;
}

void webkit_dom_html_hr_element_set_size(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::sizeAttr, convertedValue);
}

gchar* webkit_dom_html_hr_element_get_width(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::widthAttr));
    return result;
}

void webkit_dom_html_hr_element_set_width(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::widthAttr, convertedValue);
}

==> webkit2gtk_2.28.2.orig.tar.xz: webkitgtk-2.28.2/Source/WebKit/WebProcess/InjectedBundle/API/gtk/DOM/WebKitDOMHTMLHRElement.cpp <==
/*
 *  This file is part of the WebKit open source project.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 */

#include "config.h"
#include "WebKitDOMHTMLHRElement.h"

#include <WebCore/CSSImportRule.h>
#include "DOMObjectCache.h"
#include <WebCore/DOMException.h>
#include <WebCore/Document.h>
#include "GObjectEventListener.h"
#include <WebCore/HTMLNames.h>
#include <WebCore/JSExecState.h>
#include "WebKitDOMEventPrivate.h"
#include "WebKitDOMEventTarget.h"
#include "WebKitDOMHTMLHRElementPrivate.h"
#include "WebKitDOMNodePrivate.h"
#include "WebKitDOMPrivate.h"
#include "ConvertToUTF8String.h"
#include <wtf/GetPtr.h>
#include <wtf/RefPtr.h>

G_GNUC_BEGIN_IGNORE_DEPRECATIONS;

namespace WebKit {

WebKitDOMHTMLHRElement* kit(WebCore::HTMLHRElement* obj)
{
    return WEBKIT_DOM_HTML_HR_ELEMENT(kit(static_cast<WebCore::Node*>(obj)));
}

WebCore::HTMLHRElement* core(WebKitDOMHTMLHRElement* request)
{
    return request ? static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(request)->coreObject) : 0;
}

WebKitDOMHTMLHRElement* wrapHTMLHRElement(WebCore::HTMLHRElement* coreObject)
{
    ASSERT(coreObject);
    return WEBKIT_DOM_HTML_HR_ELEMENT(g_object_new(WEBKIT_DOM_TYPE_HTML_HR_ELEMENT, "core-object", coreObject, nullptr));
}

} // namespace WebKit

static gboolean webkit_dom_html_hr_element_dispatch_event(WebKitDOMEventTarget* target, WebKitDOMEvent* event, GError** error)
{
    WebCore::Event* coreEvent = WebKit::core(event);
    if (!coreEvent)
        return false;
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);

    auto result = coreTarget->dispatchEventForBindings(*coreEvent);
    if (result.hasException()) {
        auto description = WebCore::DOMException::description(result.releaseException().code());
        g_set_error_literal(error, g_quark_from_string("WEBKIT_DOM"), description.legacyCode, description.name);
        return false;
    }
    return result.releaseReturnValue();
}

static gboolean webkit_dom_html_hr_element_add_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::addEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static gboolean webkit_dom_html_hr_element_remove_event_listener(WebKitDOMEventTarget* target, const char* eventName, GClosure* handler, gboolean useCapture)
{
    WebCore::HTMLHRElement* coreTarget = static_cast<WebCore::HTMLHRElement*>(WEBKIT_DOM_OBJECT(target)->coreObject);
    return WebKit::GObjectEventListener::removeEventListener(G_OBJECT(target), coreTarget, eventName, handler, useCapture);
}

static void webkit_dom_html_hr_element_dom_event_target_init(WebKitDOMEventTargetIface* iface)
{
    iface->dispatch_event = webkit_dom_html_hr_element_dispatch_event;
    iface->add_event_listener = webkit_dom_html_hr_element_add_event_listener;
    iface->remove_event_listener = webkit_dom_html_hr_element_remove_event_listener;
}

G_DEFINE_TYPE_WITH_CODE(WebKitDOMHTMLHRElement, webkit_dom_html_hr_element, WEBKIT_DOM_TYPE_HTML_ELEMENT, G_IMPLEMENT_INTERFACE(WEBKIT_DOM_TYPE_EVENT_TARGET, webkit_dom_html_hr_element_dom_event_target_init))

enum {
    DOM_HTML_HR_ELEMENT_PROP_0,
    DOM_HTML_HR_ELEMENT_PROP_ALIGN,
    DOM_HTML_HR_ELEMENT_PROP_NO_SHADE,
    DOM_HTML_HR_ELEMENT_PROP_SIZE,
    DOM_HTML_HR_ELEMENT_PROP_WIDTH,
};

static void webkit_dom_html_hr_element_set_property(GObject* object, guint propertyId, const GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLHRElement* self = WEBKIT_DOM_HTML_HR_ELEMENT(object);

    switch (propertyId) {
    case DOM_HTML_HR_ELEMENT_PROP_ALIGN:
        webkit_dom_html_hr_element_set_align(self, g_value_get_string(value));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_NO_SHADE:
        webkit_dom_html_hr_element_set_no_shade(self, g_value_get_boolean(value));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_SIZE:
        webkit_dom_html_hr_element_set_size(self, g_value_get_string(value));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_WIDTH:
        webkit_dom_html_hr_element_set_width(self, g_value_get_string(value));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_hr_element_get_property(GObject* object, guint propertyId, GValue* value, GParamSpec* pspec)
{
    WebKitDOMHTMLHRElement* self = WEBKIT_DOM_HTML_HR_ELEMENT(object);

    switch (propertyId) {
    case DOM_HTML_HR_ELEMENT_PROP_ALIGN:
        g_value_take_string(value, webkit_dom_html_hr_element_get_align(self));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_NO_SHADE:
        g_value_set_boolean(value, webkit_dom_html_hr_element_get_no_shade(self));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_SIZE:
        g_value_take_string(value, webkit_dom_html_hr_element_get_size(self));
        break;
    case DOM_HTML_HR_ELEMENT_PROP_WIDTH:
        g_value_take_string(value, webkit_dom_html_hr_element_get_width(self));
        break;
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, propertyId, pspec);
        break;
    }
}

static void webkit_dom_html_hr_element_class_init(WebKitDOMHTMLHRElementClass* requestClass)
{
    GObjectClass* gobjectClass = G_OBJECT_CLASS(requestClass);
    gobjectClass->set_property = webkit_dom_html_hr_element_set_property;
    gobjectClass->get_property = webkit_dom_html_hr_element_get_property;

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_HR_ELEMENT_PROP_ALIGN,
        g_param_spec_string(
            "align",
            "HTMLHRElement:align",
            "read-write gchar* HTMLHRElement:align",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_HR_ELEMENT_PROP_NO_SHADE,
        g_param_spec_boolean(
            "no-shade",
            "HTMLHRElement:no-shade",
            "read-write gboolean HTMLHRElement:no-shade",
            FALSE,
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_HR_ELEMENT_PROP_SIZE,
        g_param_spec_string(
            "size",
            "HTMLHRElement:size",
            "read-write gchar* HTMLHRElement:size",
            "",
            WEBKIT_PARAM_READWRITE));

    g_object_class_install_property(
        gobjectClass,
        DOM_HTML_HR_ELEMENT_PROP_WIDTH,
        g_param_spec_string(
            "width",
            "HTMLHRElement:width",
            "read-write gchar* HTMLHRElement:width",
            "",
            WEBKIT_PARAM_READWRITE));

}

static void webkit_dom_html_hr_element_init(WebKitDOMHTMLHRElement* request)
{
    UNUSED_PARAM(request);
}

gchar* webkit_dom_html_hr_element_get_align(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::alignAttr));
    return result;
}

void webkit_dom_html_hr_element_set_align(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::alignAttr, convertedValue);
}

gboolean webkit_dom_html_hr_element_get_no_shade(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), FALSE);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gboolean result = item->hasAttributeWithoutSynchronization(WebCore::HTMLNames::noshadeAttr);
    return result;
}

void webkit_dom_html_hr_element_set_no_shade(WebKitDOMHTMLHRElement* self, gboolean value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    WebCore::HTMLHRElement* item = WebKit::core(self);
    item->setBooleanAttribute(WebCore::HTMLNames::noshadeAttr, value);
}

gchar* webkit_dom_html_hr_element_get_size(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::sizeAttr));
    return result;
}

void webkit_dom_html_hr_element_set_size(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::sizeAttr, convertedValue);
}

gchar* webkit_dom_html_hr_element_get_width(WebKitDOMHTMLHRElement* self)
{
    WebCore::JSMainThreadNullState state;
    g_return_val_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self), 0);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    gchar* result = convertToUTF8String(item->attributeWithoutSynchronization(WebCore::HTMLNames::widthAttr));
    return result;
}

void webkit_dom_html_hr_element_set_width(WebKitDOMHTMLHRElement* self, const gchar* value)
{
    WebCore::JSMainThreadNullState state;
    g_return_if_fail(WEBKIT_DOM_IS_HTML_HR_ELEMENT(self));
    g_return_if_fail(value);
    WebCore::HTMLHRElement* item = WebKit::core(self);
    WTF::String convertedValue = WTF::String::fromUTF8(value);
    item->setAttributeWithoutSynchronization(WebCore::HTMLNames::widthAttr, convertedValue);
}

G_GNUC_END_IGNORE_DEPRECATIONS;
